<?PHP
///////////////////////////////////////////////////////////////////////////
// lib.php - functions for web output for selecting and sending  emails
// * 2005-08-31
// * Version 0.2
// * author: oliver grimm ogrimm@tfh-berlin.de
// * http://learn.tfh-berlin.de
//
// Library of all general-purpose Moodle PHP functions and constants
// that produce HTML output
//
///////////////////////////////////////////////////////////////////////////
//                                                                       //
// NOTICE OF COPYRIGHT                                                   //
//                                                                       //
// Moodle - Modular Object-Oriented Dynamic Learning Environment         //
//          http://moodle.com                                            //
//                                                                       //
// Copyright (C) 2005  Oliver Grimm  http://learn.tfh-berlin.de          //
//                                                                       //
// This program is free software; you can redistribute it and/or modify  //
// it under the terms of the GNU General Public License as published by  //
// the Free Software Foundation; either version 2 of the License, or     //
// (at your option) any later version.                                   //
//                                                                       //
// This program is distributed in the hope that it will be useful,       //
// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         //
// GNU General Public License for more details:                          //
//                                                                       //
//          http://www.gnu.org/copyleft/gpl.html                         //
//                                                                       //
///////////////////////////////////////////////////////////////////////////


// Returns full usernames from a given course with a trailing semicolon
// (usefull for being displayed in a recpient list)
function get_full_user_name($user, $course) {
    global $CFG,$USER;
	$isteacher = isteacher($course->id);
	return fullname($user, $isteacher)."; ";
}

// Returns an array of full usernames from  a given course
function get_full_user_names($users,$course) {
	$recipients = "";
	foreach ($users as $user) {
		$recipients .= get_full_user_name($user, $course);
	}
	return substr($recipients,0,strlen($recipients)-2);
}

// Print all the full name of given course seperated by a semicolon
function print_full_user_names($users,$course) {
	foreach ($users as $user) {
		$recipients .= get_full_user_name($user, $course);
	}
	echo substr($recipients,0,strlen($recipients)-2);
}

// Generate HTML-Code to select users to recieve an email
function get_full_user_names_selection($users, $course) {
	$rowcounter = 0;
	$recipients = "<table>";
	foreach ($users as $user) {
		$recipients .= ($rowcounter == 0) ? "<tr>" : "";
		$recipients .= '<td><input name="mailrecip[]" type="checkbox" value="'.$user->id.'">'
						  .get_full_user_name($user, $course).'</td> ';
		$recipients .= ($rowcounter == 1) ? "</tr>" : "";
		$rowcounter = ($rowcounter == 1) ? 0 : $rowcounter+1;
	}
	$recipients .= "</table>";

	//return substr($recipients,0,strlen($recipients)-3);
	return $recipients;
}

// Generate HTML-Code to select groups to send an email to
function get_group_selection($groups) {
	$rowcounter = 0;
	$recipients = "";
	if(empty($groups))
	  return null;
	foreach($groups as $group) {
		$g = $group;
		$recipients .= '<input name="mailrecip[]" type="checkbox" value="'.$g->id.'">'.$g->name.'<br />';
		$rowcounter=+1;
	}
	return ($rowcounter > 0) ? $recipients : null;
}

// Generate and display HTML-Code to select users to recieve an email
function print_full_user_names_selection($users, $course) {
	foreach ($users as $user) {
		$recipients .= ' <input name="mailrecip[]" type="checkbox" value="'.$user->email.'">'
					  .get_full_user_name($user, $course).' ';
	}
	echo substr($recipients,0,strlen($recipients)-3);
}

// Retrieve all needed data form db for the selected groups
function get_recipient_list_from_groupid($id) {
	global $CFG;

	$gr = get_records_sql("SELECT id, userid
	                                 FROM {$CFG->prefix}groups_members
	                                 WHERE groupid = $id");
	$g_users = array();
	foreach($gr as $u){
		$t=$u;
		array_push($g_users, get_recipient_list_from_id($t->userid));
	}
	return $g_users;
}

// get all teachers of all courses (site wide => for admin only)
function get_all_teachers_names() {
	global $CFG;
	$query = " SELECT u.id, u.firstname, u.lastname, u.email 
			   FROM {$CFG->prefix}user u, {$CFG->prefix}user_teachers t
			   WHERE t.userid = u.id 
			   GROUP BY u.id
			   ORDER BY u.lastname ASC";
	$teachers = get_records_sql($query);
	$str_teachers = "";
	$counter = 0;
	foreach($teachers as $teacher) {
		$str_teachers .= $teacher->firstname ." , " . $teacher->lastname ."; ";
		$counter += 1;
	}

	return 	print_names($str_teachers, $counter);// $str_teachers; 
}

// get all coursecreator's names(site wide => for admin only)
function get_all_course_creators_names() {
	global $CFG;
	$query = " SELECT u.id, u.firstname, u.lastname, u.email 
			   FROM {$CFG->prefix}user u, {$CFG->prefix}user_coursecreators c
			   WHERE c.userid = u.id 
			   GROUP BY u.id
			   ORDER BY u.lastname ASC";
	$creators = get_records_sql($query);
	$str_creators = "";
	$counter = 0;
	foreach($creators as $creator) {
		$str_creators .= $creator->firstname ." , " . $creator->lastname ."; ";
		$counter += 1;
	}
	return 	print_names($str_creators, $counter);
}

// get all user's names (site wide => for admin only)
function get_all_user_names() {
	global $CFG;
	$query = " SELECT id, firstname, lastname, email 
			   FROM {$CFG->prefix}user
			   ORDER BY lastname ASC";
	$users = get_records_sql($query);
	$str_users = "";
	$counter = 0;
	foreach($users as $user) {
		$str_users .= $user->firstname ." , " . $user->lastname ."; ";
		$counter += 1;
	}
	return 	print_names($str_users, $counter);
}

// get all students's names (site wide => for admin only)
function get_all_student_names() {
	global $CFG;
	$query = " SELECT u.id, u.firstname, u.lastname, u.email 
			   FROM {$CFG->prefix}user u, {$CFG->prefix}user_students s
			   WHERE s.userid = u.id 
			   GROUP BY u.id
			   ORDER BY u.lastname ASC";
	$students = get_records_sql($query);
	$str_students = "";
	$counter = 0;
	foreach($students as $student) {
		$str_students .= $student->firstname ." , " . $student->lastname ."; ";
		$counter += 1;
	}
	return print_names($str_students, $counter);
}

// retrieve all teachers (site wide => for admin only)
function get_teachers_sitewide() {
    global $CFG;
    return get_records_sql("SELECT u.*
			   FROM {$CFG->prefix}user u, {$CFG->prefix}user_teachers t
			   WHERE t.userid = u.id 
			   GROUP BY u.id
			   ORDER BY u.lastname ASC");
}

// retrieve all students (site wide => for admin only)
function get_students_sitewide() {
    global $CFG;
    return get_records_sql(" SELECT u.*
			   FROM {$CFG->prefix}user u, {$CFG->prefix}user_students s
			   WHERE s.userid = u.id 
			   GROUP BY u.id
			   ORDER BY u.lastname ASC");
}



// generate html source code for recipients first- and lastnames
function print_names($names, $count) {
	global $CFG;
	// max amount of displayed names 
	$max = 20;
	$fulldisplay = ($count > $max) ? false : true;
	$html  = '<a href="JavaScript: toggleRecipList();" title="'.get_string("recipients","email") .'"><img id="toogleimg" src="' . $CFG->wwwroot. '/email/'; 
	$html .= ($fulldisplay) ? 'open' : 'close';
	$html .= '.gif" border="0" /></a>';
	$html .= '<div id="sendmail_recipient_counter" ';
	$html .= ($fulldisplay) ? 'style="display: none;"' : 'style="display:inline;"';
	$html .= '>' . $count . ' ' . get_string("recipients","email") . '</div>';
	$html .= '<div id="sendmail_recipients"';
	$html .= (!$fulldisplay) ? 'style="display: none;"' : 'style="display:inline;"';
	$html .= '>' . $names . '</div>';

	return $html;
	
}


// Retrieve all needed data form db for the selected recipients
function get_recipient_list_from_id($id) {
	global $CFG;
	return get_record_sql("SELECT id, firstname, lastname, email, mailformat
	                                 FROM {$CFG->prefix}user
	                                 WHERE id = $id");
}




// Generate a list of all recipients with fullname and email
// This List is attached to the sender's backup copy
function get_formated_recipients_list($headline, $recipients, $html=true) {
	global $CFG;
	$recipients_list = "";
	if($html) {
		$recipients_list .= "<p>" . $headline . "</p>";
		$recipients_list .= "<p /><hr /><p />";
		$recipients_list .= "<table border=\"0\"><tr>";
		$recipients_list .= "<th>".get_string("lastname","moodle")."</th>";
		$recipients_list .= "<th>".get_string("firstname","moodle")."</th>";
		$recipients_list .= "<th>".get_string("email","moodle")."</th></tr>";
		
		foreach($recipients as $recipient) {
			$recipients_list .= "<tr><td>" . $recipient->lastname ."</td>" .
					    "<td>" . $recipient->firstname ."</td>" .
					    "<td>" . $recipient->email."</td></tr>";
		    if($recipient->errmsg) 
			    $recipients_list .= "<tr><td>".get_string("error","moodle").":</td><td colspan=\"2\">" . $recipient->errmsg ."</td></tr>";
		}
		$recipients_list .= "</table>";
	}

	else {
		$recipients_list .= "\n\n" . $headline;
		$recipients_list .= "\n\n".get_string("lastname","moodle")."\t\t\t";
		$recipients_list .= get_string("firststname","moodle")."\t\t\t";
		$recipients_list .= get_string("email","moodle")."\t\t\t\n";
		
		foreach($recipients as $recipient) {
			$recipients_list .= $recipient->lastname. "\t\t\t" .
					    $recipient->firstname . "\t\t\t" .
					    $recipient->email . "\t\t\t\n";
	    if($recipient->errmsg) 
			    $recipients_list .= get_string("error","moodle").":\t\t\t" . $recipient->errmsg ."\n";					    
		}
	}

	return $recipients_list;

}

// Security Function: Check wether this specific user is allowed to send mails 
function checkpermissions($course_id, $sel, $settings) {
	global $CFG, $USER;
	$teacher = isteacher($course_id);
 		
	if (($settings->block_email_studentsallowed  || $teacher) && $CFG->block_email_studentsallowed) {

		switch($sel) {
			case 'all':
				if(($settings->block_email_allow2all  || $teacher) && $CFG->block_email_allow2all)  {
					return true;
				}
				break;
				
			case 'allteachers':	
				if(($settings->block_email_allow2teachers  || $teacher) && $CFG->block_email_allow2teachers){
					return true;		
				}	
				break;
				
			case 'allstudents':			
				if(($settings->block_email_allow2students  || $teacher) && $CFG->block_email_allow2students){
					return true;		
				}

				break;
			case 'select':				
				if(($settings->block_email_allow2selected  || $teacher) && $CFG->block_email_allow2selected){    	
					return true;		
				}
				
				break;
			case 'group':	
				if(($settings->block_email_allow2groups  || $teacher) && $CFG->block_email_allow2groups){    	
					return true;		
				}
				break;
		}

	}
	
	return false;
	
}


function get_email_settings($course_id, $block_instance_id) {
	//$this->config = unserialize(base64_decode($instance->configdata));
	global $CFG;
	$query = "SELECT configdata FROM {$CFG->prefix}block_instance WHERE pageid = $course_id AND id = $block_instance_id";
	$settings = get_record_sql($query);
	return unserialize(base64_decode($settings->configdata));	
}

?>
